translate.misc.typecheck.Fake_generator

Package translate :: Package misc :: Package typecheck :: Class Fake_generator |
[hide private]
[frames] | no frames]

# Class Fake_generator

source code

Instance Methods | [hide private]
__init__(self, real_gen, signature) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
next(self) | source code
__del__(self) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, real_gen, signature) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)